@@ -16,20 +16,16 @@
  */
 package org.apache.qpid.jms.consumer;
 
-import static org.junit.jupiter.api.Assertions.assertThrows;
-
-import javax.jms.JMSException;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageListener;
-import javax.jms.Queue;
-import javax.jms.Session;
+import jakarta.jms.JMSException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageListener;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
 
 import org.apache.qpid.jms.JmsConnectionTestSupport;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInfo;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Tests MessageConsumer method contracts after the MessageConsumer is closed.
@@ -41,73 +37,54 @@ public class JmsMessageConsumerClosedTest extends JmsConnectionTestSupport {
     protected MessageConsumer createConsumer() throws Exception {
         connection = createConnectionToMockProvider();
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue destination = session.createQueue(_testMethodName);
+        Queue destination = session.createQueue(_testName.getMethodName());
         MessageConsumer consumer = session.createConsumer(destination);
         consumer.close();
         return consumer;
     }
 
     @Override
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        super.setUp(testInfo);
+    @Before
+    public void setUp() throws Exception {
+        super.setUp();
         consumer = createConsumer();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testGetMessageSelectorFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            consumer.getMessageSelector();
-        });
+        consumer.getMessageSelector();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testGetMessageListenerFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            consumer.getMessageListener();
-        });
+        consumer.getMessageListener();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testSetMessageListenerFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            consumer.setMessageListener(new MessageListener() {
-                @Override
-                public void onMessage(Message message) {
-                }
-            });
+        consumer.setMessageListener(new MessageListener() {
+            @Override
+            public void onMessage(Message message) {
+            }
         });
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testRreceiveFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            consumer.receive();
-        });
+        consumer.receive();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testRreceiveTimedFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            consumer.receive(11);
-        });
+        consumer.receive(11);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testRreceiveNoWaitFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            consumer.receiveNoWait();
-        });
+        consumer.receiveNoWait();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000)
     public void testClose() throws Exception {
         consumer.close();
     }
