@@ -16,19 +16,15 @@
  */
 package org.apache.qpid.jms.consumer;
 
-import static org.junit.jupiter.api.Assertions.assertThrows;
-
-import javax.jms.Session;
-import javax.jms.Topic;
-import javax.jms.TopicConnection;
-import javax.jms.TopicSession;
-import javax.jms.TopicSubscriber;
+import jakarta.jms.Session;
+import jakarta.jms.Topic;
+import jakarta.jms.TopicConnection;
+import jakarta.jms.TopicSession;
+import jakarta.jms.TopicSubscriber;
 
 import org.apache.qpid.jms.JmsConnectionTestSupport;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInfo;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Tests TopicSubscriber method contracts after the TopicSubscriber is closed.
@@ -40,47 +36,35 @@ public class JmsTopicSubscriberClosedTest extends JmsConnectionTestSupport {
     protected void createTestResources() throws Exception {
         connection = createTopicConnectionToMockProvider();
         TopicSession session = ((TopicConnection) connection).createTopicSession(false, Session.AUTO_ACKNOWLEDGE);
-        Topic destination = session.createTopic(_testMethodName);
+        Topic destination = session.createTopic(_testName.getMethodName());
         subscriber = session.createSubscriber(destination);
         subscriber.close();
     }
 
     @Override
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        super.setUp(testInfo);
+    @Before
+    public void setUp() throws Exception {
+        super.setUp();
         createTestResources();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=jakarta.jms.IllegalStateException.class)
     public void testGetNoLocalFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
-            subscriber.getNoLocal();
-        });
+        subscriber.getNoLocal();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=jakarta.jms.IllegalStateException.class)
     public void testGetMessageListenerFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
-            subscriber.getMessageListener();
-        });
+        subscriber.getMessageListener();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=jakarta.jms.IllegalStateException.class)
     public void testGetMessageSelectorFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
-            subscriber.getMessageSelector();
-        });
+        subscriber.getMessageSelector();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=jakarta.jms.IllegalStateException.class)
     public void testGetTopicFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
-            subscriber.getTopic();
-        });
+        subscriber.getTopic();
     }
 }
