@@ -20,21 +20,21 @@
  */
 package org.apache.qpid.jms.integration;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
-import static org.junit.jupiter.api.Assumptions.assumeTrue;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeTrue;
 
 import java.io.IOException;
 import java.net.Socket;
 import java.security.cert.Certificate;
 import java.security.cert.X509Certificate;
 
-import javax.jms.Connection;
-import javax.jms.JMSException;
+import jakarta.jms.Connection;
+import jakarta.jms.JMSException;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLPeerUnverifiedException;
 import javax.net.ssl.SSLSession;
@@ -47,8 +47,8 @@ import org.apache.qpid.jms.test.testpeer.TestAmqpPeer;
 import org.apache.qpid.jms.transports.TransportOptions;
 import org.apache.qpid.jms.transports.TransportSupport;
 import org.apache.qpid.jms.transports.netty.NettySimpleAmqpServer;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
+
 import io.netty.handler.ssl.OpenSsl;
 
 public class SslIntegrationTest extends QpidJmsTestCase {
@@ -83,14 +83,12 @@ public class SslIntegrationTest extends QpidJmsTestCase {
 
     private final IntegrationTestFixture testFixture = new IntegrationTestFixture();
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateAndCloseSslConnectionJDK() throws Exception {
         testCreateAndCloseSslConnection(false);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateAndCloseSslConnectionOpenSSL() throws Exception {
         assumeTrue(OpenSsl.isAvailable());
         assumeTrue(OpenSsl.supportsKeyManagerFactory());
@@ -120,14 +118,12 @@ public class SslIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateSslConnectionWithServerSendingPreemptiveDataJDK() throws Exception {
         doTestCreateSslConnectionWithServerSendingPreemptiveData(false);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateSslConnectionWithServerSendingPreemptiveDataOpenSSL() throws Exception {
         assumeTrue(OpenSsl.isAvailable());
         assumeTrue(OpenSsl.supportsKeyManagerFactory());
@@ -166,14 +162,12 @@ public class SslIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateAndCloseSslConnectionWithClientAuthJDK() throws Exception {
         doTestCreateAndCloseSslConnectionWithClientAuth(false);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateAndCloseSslConnectionWithClientAuthOpenSSL() throws Exception {
         assumeTrue(OpenSsl.isAvailable());
         assumeTrue(OpenSsl.supportsKeyManagerFactory());
@@ -208,15 +202,13 @@ public class SslIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateAndCloseSslConnectionWithAliasJDK() throws Exception {
         doConnectionWithAliasTestImpl(CLIENT_KEY_ALIAS, CLIENT_DN, false);
         doConnectionWithAliasTestImpl(CLIENT2_KEY_ALIAS, CLIENT2_DN, false);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateAndCloseSslConnectionWithAliasOpenSSL() throws Exception {
         assumeTrue(OpenSsl.isAvailable());
         assumeTrue(OpenSsl.supportsKeyManagerFactory());
@@ -255,21 +247,19 @@ public class SslIntegrationTest extends QpidJmsTestCase {
             Certificate cert = peerCertificates[0];
             assertTrue(cert instanceof X509Certificate);
             String dn = ((X509Certificate)cert).getSubjectX500Principal().getName();
-            assertEquals(expectedDN, dn, "Unexpected certificate DN");
+            assertEquals("Unexpected certificate DN", expectedDN, dn);
 
             testPeer.expectClose();
             connection.close();
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateConnectionWithAliasThatDoesNotExist() throws Exception {
         doCreateConnectionWithInvalidAliasTestImpl(ALIAS_DOES_NOT_EXIST);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateConnectionWithAliasThatDoesNotRepresentKeyEntry() throws Exception {
         doCreateConnectionWithInvalidAliasTestImpl(ALIAS_CA_CERT);
     }
@@ -300,7 +290,7 @@ public class SslIntegrationTest extends QpidJmsTestCase {
                 // Expected
             }
 
-            assertNull(testPeer.getClientSocket(), "Attempt should have failed locally, peer should not have accepted any TCP connection");
+            assertNull("Attempt should have failed locally, peer should not have accepted any TCP connection", testPeer.getClientSocket());
         }
     }
 
@@ -311,8 +301,7 @@ public class SslIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected error is encountered
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateConnectionWithSslContextOverride() throws Exception {
         assertNotEquals(CLIENT_JKS_KEYSTORE, CLIENT2_JKS_KEYSTORE);
         assertNotEquals(CLIENT_DN, CLIENT2_DN);
@@ -323,8 +312,7 @@ public class SslIntegrationTest extends QpidJmsTestCase {
         doConnectionWithSslContextOverride(CLIENT2_JKS_KEYSTORE, CLIENT2_DN, false);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateConnectionWithSslContextOverrideByExtension() throws Exception {
         assertNotEquals(CLIENT_JKS_KEYSTORE, CLIENT2_JKS_KEYSTORE);
         assertNotEquals(CLIENT_DN, CLIENT2_DN);
@@ -383,7 +371,7 @@ public class SslIntegrationTest extends QpidJmsTestCase {
             Certificate cert = peerCertificates[0];
             assertTrue(cert instanceof X509Certificate);
             String dn = ((X509Certificate)cert).getSubjectX500Principal().getName();
-            assertEquals(expectedDN, dn, "Unexpected certificate DN");
+            assertEquals("Unexpected certificate DN", expectedDN, dn);
 
             testPeer.expectClose();
             connection.close();
@@ -398,8 +386,7 @@ public class SslIntegrationTest extends QpidJmsTestCase {
      *
      * @throws Exception if an unexpected error is encountered
      */
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateConnectionWithSslContextOverrideAndURIConfig() throws Exception {
         assertNotEquals(CLIENT_JKS_KEYSTORE, CLIENT2_JKS_KEYSTORE);
         assertNotEquals(CLIENT_DN, CLIENT2_DN);
@@ -455,15 +442,14 @@ public class SslIntegrationTest extends QpidJmsTestCase {
             Certificate cert = peerCertificates[0];
             assertTrue(cert instanceof X509Certificate);
             String dn = ((X509Certificate)cert).getSubjectX500Principal().getName();
-            assertEquals(expectedDN, dn, "Unexpected certificate DN");
+            assertEquals("Unexpected certificate DN", expectedDN, dn);
 
             testPeer.expectClose();
             connection.close();
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testConfigureStoresWithSslSystemProperties() throws Exception {
         // Set properties and expect connection as Client1
         setSslSystemPropertiesForCurrentTest(CLIENT_JKS_KEYSTORE, PASSWORD, CLIENT_JKS_TRUSTSTORE, PASSWORD);
@@ -501,16 +487,14 @@ public class SslIntegrationTest extends QpidJmsTestCase {
         doConfigureStoresWithSslSystemPropertiesTestImpl(CLIENT2_DN);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testConfigurePkcs12StoresWithSslSystemProperties() throws Exception {
         // Set properties and expect connection as Client1
         setSslSystemPropertiesForCurrentTest(CLIENT_PKCS12_KEYSTORE, CUSTOM_STORE_TYPE_PKCS12, PASSWORD, CLIENT_PKCS12_TRUSTSTORE, CUSTOM_STORE_TYPE_PKCS12, PASSWORD);
         doConfigureStoresWithSslSystemPropertiesTestImpl(CLIENT_DN);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testNonSslConnectionFailsToSslServer() throws Exception {
         TransportOptions serverOptions = new TransportOptions();
         serverOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
@@ -529,7 +513,7 @@ public class SslIntegrationTest extends QpidJmsTestCase {
             catch (JMSException jmse) {
                 String message = jmse.getMessage();
                 assertNotNull(message);
-                assertTrue(message.contains("Timed out while waiting to connect"), "Unexpected message: " + message);
+                assertTrue("Unexpected message: " + message, message.contains("Timed out while waiting to connect"));
             }
         }
     }
@@ -573,7 +557,7 @@ public class SslIntegrationTest extends QpidJmsTestCase {
             Certificate cert = peerCertificates[0];
             assertTrue(cert instanceof X509Certificate);
             String dn = ((X509Certificate)cert).getSubjectX500Principal().getName();
-            assertEquals(expectedDN, dn, "Unexpected certificate DN");
+            assertEquals("Unexpected certificate DN", expectedDN, dn);
 
             testPeer.expectClose();
             connection.close();
