@@ -20,27 +20,25 @@
  */
 package org.apache.qpid.jms.integration;
 
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
-import javax.jms.JMSException;
+import jakarta.jms.JMSException;
 
 import org.apache.qpid.jms.JmsConnectionFactory;
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.apache.qpid.jms.transports.TransportOptions;
 import org.apache.qpid.jms.transports.netty.NettyBlackHoleServer;
 import org.apache.qpid.jms.transports.netty.NettySimpleAmqpServer;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 
 public class WsIntegrationTest extends QpidJmsTestCase {
 
     private static final String BROKER_PKCS12_KEYSTORE = "src/test/resources/broker-pkcs12.keystore";
     private static final String PASSWORD = "password";
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testNonSslWebSocketConnectionFailsToSslServer() throws Exception {
         TransportOptions serverOptions = new TransportOptions();
         serverOptions.setKeyStoreLocation(BROKER_PKCS12_KEYSTORE);
@@ -59,13 +57,12 @@ public class WsIntegrationTest extends QpidJmsTestCase {
             catch (JMSException jmse) {
                 String message = jmse.getMessage();
                 assertNotNull(message);
-                assertTrue(message.contains("Connection failed"), "Unexpected message: " + message);
+                assertTrue("Unexpected message: " + message, message.contains("Connection failed"));
             }
         }
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testWebsocketConnectionToBlackHoleServerTimesOut() throws Exception {
         TransportOptions serverOptions = new TransportOptions();
 
@@ -81,7 +78,7 @@ public class WsIntegrationTest extends QpidJmsTestCase {
             catch (JMSException jmse) {
                 String message = jmse.getMessage();
                 assertNotNull(message);
-                assertTrue(message.contains("WebSocket handshake timed out"), "Unexpected message: " + message);
+                assertTrue("Unexpected message: " + message, message.contains("WebSocket handshake timed out"));
             }
         }
     }
