@@ -16,12 +16,11 @@
  */
 package org.apache.qpid.jms.message;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertThrows;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.EOFException;
 import java.io.IOException;
@@ -32,17 +31,17 @@ import java.util.Arrays;
 import java.util.List;
 import java.util.Map;
 
-import javax.jms.BytesMessage;
-import javax.jms.JMSException;
-import javax.jms.MessageEOFException;
-import javax.jms.MessageFormatException;
-import javax.jms.MessageNotReadableException;
-import javax.jms.MessageNotWriteableException;
+import jakarta.jms.BytesMessage;
+import jakarta.jms.JMSException;
+import jakarta.jms.MessageEOFException;
+import jakarta.jms.MessageFormatException;
+import jakarta.jms.MessageNotReadableException;
+import jakarta.jms.MessageNotWriteableException;
 
 import org.apache.qpid.jms.message.facade.JmsBytesMessageFacade;
 import org.apache.qpid.jms.message.facade.test.JmsTestBytesMessageFacade;
 import org.apache.qpid.jms.message.facade.test.JmsTestMessageFactory;
-import org.junit.jupiter.api.Test;
+import org.junit.Test;
 import org.mockito.Mockito;
 
 /**
@@ -72,7 +71,7 @@ public class JmsBytesMessageTest {
         JmsBytesMessage bytesMessage = factory.createBytesMessage();
         bytesMessage.writeBytes(bytes);
         bytesMessage.reset();
-        assertEquals(bytes.length, bytesMessage.getBodyLength(), "Message reports unexpected length");
+        assertEquals("Message reports unexpected length", bytes.length, bytesMessage.getBodyLength());
     }
 
     /**
@@ -81,12 +80,10 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test
+    @Test(expected = MessageNotReadableException.class)
     public void testGetBodyLengthOnNewMessageThrowsMessageNotReadableException() throws Exception {
-        assertThrows(MessageNotReadableException.class, () -> {
-            JmsBytesMessage bytesMessage = factory.createBytesMessage();
-            bytesMessage.getBodyLength();
-        });
+        JmsBytesMessage bytesMessage = factory.createBytesMessage();
+        bytesMessage.getBodyLength();
     }
 
     @Test
@@ -94,7 +91,7 @@ public class JmsBytesMessageTest {
         JmsBytesMessage bytesMessage = factory.createBytesMessage();
         bytesMessage.onDispatch();
         //verify attempting to read bytes returns -1, i.e EOS
-        assertEquals(END_OF_STREAM, bytesMessage.readBytes(new byte[1]), "Expected input stream to be at end but data was returned");
+        assertEquals("Expected input stream to be at end but data was returned", END_OF_STREAM, bytesMessage.readBytes(new byte[1]));
     }
 
     @Test
@@ -111,9 +108,10 @@ public class JmsBytesMessageTest {
         assertTrue(Arrays.equals(content, receivedBytes));
 
         // verify no more bytes remain, i.e EOS
-        assertEquals(END_OF_STREAM, bytesMessage.readBytes(new byte[1]), "Expected input stream to be at end but data was returned");
+        assertEquals("Expected input stream to be at end but data was returned",
+                     END_OF_STREAM, bytesMessage.readBytes(new byte[1]));
 
-        assertEquals(content.length, bytesMessage.getBodyLength(), "Message reports unexpected length");
+        assertEquals("Message reports unexpected length", content.length, bytesMessage.getBodyLength());
     }
 
     /**
@@ -122,16 +120,14 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test
+    @Test(expected = MessageNotWriteableException.class)
     public void testReceivedBytesMessageThrowsMessageNotWriteableExceptionOnWriteBytes() throws Exception {
-        assertThrows(MessageNotWriteableException.class, () -> {
-            byte[] content = "myBytesData".getBytes();
-            JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
+        byte[] content = "myBytesData".getBytes();
+        JmsTestBytesMessageFacade facade = new JmsTestBytesMessageFacade(content);
 
-            JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
-            bytesMessage.onDispatch();
-            bytesMessage.writeBytes(content);
-        });
+        JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
+        bytesMessage.onDispatch();
+        bytesMessage.writeBytes(content);
     }
 
     /**
@@ -140,13 +136,11 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test
+    @Test(expected = MessageNotReadableException.class)
     public void testNewBytesMessageThrowsMessageNotReadableOnReadBytes() throws Exception {
-        assertThrows(MessageNotReadableException.class, () -> {
-            JmsBytesMessage bytesMessage = factory.createBytesMessage();
-            byte[] receivedBytes = new byte[1];
-            bytesMessage.readBytes(receivedBytes);
-        });
+        JmsBytesMessage bytesMessage = factory.createBytesMessage();
+        byte[] receivedBytes = new byte[1];
+        bytesMessage.readBytes(receivedBytes);
     }
 
     /**
@@ -162,9 +156,9 @@ public class JmsBytesMessageTest {
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
-        assertTrue(bytesMessage.isReadOnlyBody(), "Message should not be writable");
+        assertTrue("Message should not be writable", bytesMessage.isReadOnlyBody());
         bytesMessage.clearBody();
-        assertFalse(bytesMessage.isReadOnlyBody(), "Message should be writable");
+        assertFalse("Message should be writable", bytesMessage.isReadOnlyBody());
     }
 
     /**
@@ -181,11 +175,11 @@ public class JmsBytesMessageTest {
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
 
-        assertTrue(facade.getBodyLength() > 0, "Expected message content but none was present");
-        assertEquals(1, facade.getInputStream().read(new byte[1]), "Expected data from facade");
+        assertTrue("Expected message content but none was present", facade.getBodyLength() > 0);
+        assertEquals("Expected data from facade", 1, facade.getInputStream().read(new byte[1]));
         bytesMessage.clearBody();
-        assertTrue(facade.getBodyLength() == 0, "Expected no message content from facade");
-        assertEquals(END_OF_STREAM, facade.getInputStream().read(new byte[1]), "Expected no data from facade, but got some");
+        assertTrue("Expected no message content from facade", facade.getBodyLength() == 0);
+        assertEquals("Expected no data from facade, but got some", END_OF_STREAM, facade.getInputStream().read(new byte[1]));
     }
 
     /**
@@ -201,7 +195,7 @@ public class JmsBytesMessageTest {
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
         bytesMessage.onDispatch();
-        assertEquals(content.length, bytesMessage.getBodyLength(), "Unexpected message length");
+        assertEquals("Unexpected message length", content.length, bytesMessage.getBodyLength());
         bytesMessage.clearBody();
 
         try {
@@ -253,10 +247,10 @@ public class JmsBytesMessageTest {
 
         JmsBytesMessage bytesMessage = new JmsBytesMessage(facade);
 
-        assertFalse(bytesMessage.isReadOnlyBody(), "Message should be writable");
+        assertFalse("Message should be writable", bytesMessage.isReadOnlyBody());
         bytesMessage.writeBytes(content);
         bytesMessage.reset();
-        assertTrue(bytesMessage.isReadOnlyBody(), "Message should not be writable");
+        assertTrue("Message should not be writable", bytesMessage.isReadOnlyBody());
 
         // retrieve the bytes, check they match
         byte[] resetBytes = new byte[content.length];
@@ -274,7 +268,7 @@ public class JmsBytesMessageTest {
     public void testReadBytesWithZeroLengthDestination() throws Exception {
         JmsBytesMessage bytesMessage = factory.createBytesMessage();
         bytesMessage.reset();
-        assertEquals(0, bytesMessage.readBytes(new byte[0]), "Did not expect any bytes to be read");
+        assertEquals("Did not expect any bytes to be read", 0, bytesMessage.readBytes(new byte[0]));
     }
 
     /**
@@ -283,14 +277,12 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test
+    @Test(expected=IndexOutOfBoundsException.class)
     public void testReadBytesWithNegativeLengthThrowsIOOBE() throws Exception
     {
-        assertThrows(IndexOutOfBoundsException.class, () -> {
-            JmsBytesMessage bytesMessage = factory.createBytesMessage();
-            bytesMessage.reset();
-            bytesMessage.readBytes(new byte[0], -1);
-        });
+        JmsBytesMessage bytesMessage = factory.createBytesMessage();
+        bytesMessage.reset();
+        bytesMessage.readBytes(new byte[0], -1);
     }
 
     /**
@@ -300,13 +292,11 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test
+    @Test(expected=IndexOutOfBoundsException.class)
     public void testReadBytesWithLengthGreatThanArraySizeThrowsIOOBE() throws Exception {
-        assertThrows(IndexOutOfBoundsException.class, () -> {
-            JmsBytesMessage bytesMessage = factory.createBytesMessage();
-            bytesMessage.reset();
-            bytesMessage.readBytes(new byte[1], 2);
-        });
+        JmsBytesMessage bytesMessage = factory.createBytesMessage();
+        bytesMessage.reset();
+        bytesMessage.readBytes(new byte[1], 2);
     }
 
     /**
@@ -315,12 +305,10 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test
+    @Test(expected=NullPointerException.class)
     public void testWriteObjectWithNullThrowsNPE() throws Exception {
-        assertThrows(NullPointerException.class, () -> {
-            JmsBytesMessage bytesMessage = factory.createBytesMessage();
-            bytesMessage.writeObject(null);
-        });
+        JmsBytesMessage bytesMessage = factory.createBytesMessage();
+        bytesMessage.writeObject(null);
     }
 
     /**
@@ -329,12 +317,10 @@ public class JmsBytesMessageTest {
      *
      * @throws Exception if an error occurs during the test.
      */
-    @Test
+    @Test(expected=MessageFormatException.class)
     public void testWriteObjectWithIllegalTypeThrowsMFE() throws Exception {
-        assertThrows(MessageFormatException.class, () -> {
-            JmsBytesMessage bytesMessage = factory.createBytesMessage();
-            bytesMessage.writeObject(new Object());
-        });
+        JmsBytesMessage bytesMessage = factory.createBytesMessage();
+        bytesMessage.writeObject(new Object());
     }
 
     @Test
@@ -438,23 +424,6 @@ public class JmsBytesMessageTest {
         assertTrue(msg.readUTF().equals(str));
     }
 
-    @Test
-    public void testReadUTFMessageFormatExceptionDoesNotAdvanceReadPointer() throws Exception {
-        JmsBytesMessage msg = factory.createBytesMessage();
-        msg.writeShort((short) 2);
-        msg.writeByte((byte) 0xC0);
-        msg.writeByte((byte) 0x00);
-        msg.reset();
-
-        assertThrows(MessageFormatException.class, msg::readUTF);
-
-        assertEquals(2, msg.readUnsignedShort());
-        assertEquals((byte) 0xC0, msg.readByte());
-        assertEquals((byte) 0x00, msg.readByte());
-
-        assertThrows(MessageEOFException.class, msg::readByte);
-    }
-
     @Test
     public void testReadBytesbyteArray() throws JMSException {
         JmsBytesMessage msg = factory.createBytesMessage();
