@@ -16,12 +16,12 @@
  */
 package org.apache.qpid.jms.provider.failover;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertFalse;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.net.URI;
 import java.util.ArrayList;
@@ -32,12 +32,12 @@ import java.util.Map;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.Connection;
-import javax.jms.Destination;
-import javax.jms.JMSException;
-import javax.jms.MessageProducer;
-import javax.jms.Queue;
-import javax.jms.Session;
+import jakarta.jms.Connection;
+import jakarta.jms.Destination;
+import jakarta.jms.JMSException;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
 
 import org.apache.qpid.jms.JmsConnectionFactory;
 import org.apache.qpid.jms.meta.JmsConnectionInfo;
@@ -48,11 +48,9 @@ import org.apache.qpid.jms.provider.DefaultProviderListener;
 import org.apache.qpid.jms.provider.ProviderFuture;
 import org.apache.qpid.jms.provider.ProviderFutureFactory;
 import org.apache.qpid.jms.test.Wait;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInfo;
-import org.junit.jupiter.api.Timeout;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -70,10 +68,8 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
     private JmsConnectionInfo connection;
 
     @Override
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        super.setUp(testInfo);
-
+    @Before
+    public void setUp() throws Exception {
         uris = new ArrayList<URI>();
 
         uris.add(new URI("mock://192.168.2.1:5672"));
@@ -82,10 +78,12 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         uris.add(new URI("mock://192.168.2.4:5672"));
 
         connection = createConnectionInfo();
+
+        super.setUp();
     }
 
     @Override
-    @AfterEach
+    @After
     public void tearDown() throws Exception {
         if (provider != null) {
             provider.close();
@@ -93,8 +91,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         super.tearDown();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateProviderOnlyUris() {
         provider = new FailoverProvider(uris, Collections.emptyMap(), futuresFactory);
         assertEquals(FailoverUriPool.DEFAULT_RANDOMIZE_ENABLED, provider.isRandomize());
@@ -103,8 +100,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertTrue(provider.getNestedOptions().isEmpty());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateProviderOnlyNestedOptions() {
         Map<String, String> options = new HashMap<String, String>();
         options.put("transport.tcpNoDelay", "true");
@@ -117,8 +113,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertTrue(provider.getNestedOptions().containsKey("transport.tcpNoDelay"));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateProviderWithNestedOptions() {
         provider = new FailoverProvider(uris, Collections.<String, String>emptyMap(), futuresFactory);
         assertEquals(FailoverUriPool.DEFAULT_RANDOMIZE_ENABLED, provider.isRandomize());
@@ -127,8 +122,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertTrue(provider.getNestedOptions().isEmpty());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testProviderListener() {
         provider = new FailoverProvider(uris, Collections.<String, String>emptyMap(), futuresFactory);
         assertNull(provider.getProviderListener());
@@ -136,41 +130,38 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertNotNull(provider.getProviderListener());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testGetRemoteURI() throws Exception {
         provider = new FailoverProvider(uris, Collections.<String, String>emptyMap(), futuresFactory);
 
         assertNull(provider.getRemoteURI());
         provider.connect(connection);
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have a remote URI after connect", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return provider.getRemoteURI() != null;
             }
-        }, TimeUnit.SECONDS.toMillis(20), 10), "Should have a remote URI after connect");
+        }, TimeUnit.SECONDS.toMillis(20), 10));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testToString() throws Exception {
         provider = new FailoverProvider(uris, Collections.<String, String>emptyMap(), futuresFactory);
 
         assertNotNull(provider.toString());
         provider.connect(connection);
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Should have a mock scheme after connect", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 LOG.info("FailoverProvider: toString = {}", provider.toString());
                 return provider.toString().contains("mock://");
             }
-        }, TimeUnit.SECONDS.toMillis(20), 10), "Should have a mock scheme after connect");
+        }, TimeUnit.SECONDS.toMillis(20), 10));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testConnectToMock() throws Exception {
         provider = new FailoverProvider(uris, Collections.<String, String>emptyMap(), futuresFactory);
         assertEquals(FailoverUriPool.DEFAULT_RANDOMIZE_ENABLED, provider.isRandomize());
@@ -201,8 +192,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(1, mockPeer.getContextStats().getConnectionAttempts());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCannotStartWithoutListener() throws Exception {
         provider = new FailoverProvider(uris, Collections.<String, String>emptyMap(), futuresFactory);
         assertEquals(FailoverUriPool.DEFAULT_RANDOMIZE_ENABLED, provider.isRandomize());
@@ -218,8 +208,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         provider.close();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testStartupMaxReconnectAttempts() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://localhost?mock.failOnConnect=true)" +
@@ -243,8 +232,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(5, mockPeer.getContextStats().getCloseAttempts());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testMaxReconnectAttemptsWithOneURI() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://localhost1?mock.failOnConnect=true)" +
@@ -268,8 +256,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(5, mockPeer.getContextStats().getCloseAttempts());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testMaxReconnectAttemptsWithMultipleURIs() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://192.168.2.1?mock.failOnConnect=true," +
@@ -297,8 +284,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(15, mockPeer.getContextStats().getCloseAttempts());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testMaxReconnectAttemptsWithBackOff() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://localhost?mock.failOnConnect=true)" +
@@ -324,8 +310,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(5, mockPeer.getContextStats().getCloseAttempts());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testFailureOnCloseIsSwallowed() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://localhost?mock.failOnClose=true)");
@@ -339,8 +324,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(1, mockPeer.getContextStats().getCloseAttempts());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testSessionLifeCyclePassthrough() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://localhost)");
@@ -354,8 +338,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(1, mockPeer.getContextStats().getDestroyResourceCalls(JmsSessionInfo.class));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testConsumerLifeCyclePassthrough() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://localhost)");
@@ -363,7 +346,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         Connection connection = factory.createConnection();
         connection.start();
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Destination destination = session.createTopic(_testMethodName);
+        Destination destination = session.createTopic(_testName.getMethodName());
         session.createConsumer(destination).close();
         connection.close();
 
@@ -372,8 +355,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(1, mockPeer.getContextStats().getDestroyResourceCalls(JmsConsumerInfo.class));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testProducerLifeCyclePassthrough() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://localhost)");
@@ -381,7 +363,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         Connection connection = factory.createConnection();
         connection.start();
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Destination destination = session.createTopic(_testMethodName);
+        Destination destination = session.createTopic(_testName.getMethodName());
         session.createProducer(destination).close();
         connection.close();
 
@@ -389,8 +371,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(1, mockPeer.getContextStats().getDestroyResourceCalls(JmsProducerInfo.class));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testSessionRecoverPassthrough() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://localhost)");
@@ -404,8 +385,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(1, mockPeer.getContextStats().getRecoverCalls());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testSessionUnsubscribePassthrough() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://localhost)");
@@ -419,8 +399,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(1, mockPeer.getContextStats().getUnsubscribeCalls());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testSendMessagePassthrough() throws Exception {
         JmsConnectionFactory factory = new JmsConnectionFactory(
             "failover:(mock://localhost)");
@@ -437,8 +416,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(1, mockPeer.getContextStats().getSendCalls());
     }
 
-    @Test
-    @Timeout(10)
+    @Test(timeout=10000)
     public void testTimeoutsSetFromConnectionInfo() throws Exception {
         final long CONNECT_TIMEOUT = TimeUnit.SECONDS.toMillis(4);
         final long CLOSE_TIMEOUT = TimeUnit.SECONDS.toMillis(5);
@@ -472,15 +450,13 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(REQUEST_TIMEOUT, provider.getRequestTimeout());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testAmqpOpenServerListActionDefault() {
         provider = new FailoverProvider(uris, Collections.emptyMap(), futuresFactory);
         assertEquals("REPLACE", provider.getAmqpOpenServerListAction());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testSetGetAmqpOpenServerListAction() {
         provider = new FailoverProvider(uris, Collections.emptyMap(), futuresFactory);
         String action = "ADD";
@@ -490,8 +466,7 @@ public class FailoverProviderTest extends FailoverProviderTestSupport {
         assertEquals(action, provider.getAmqpOpenServerListAction());
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testSetInvalidAmqpOpenServerListActionThrowsIAE() {
         provider = new FailoverProvider(uris, Collections.emptyMap(), futuresFactory);
         try {
