@@ -16,22 +16,19 @@
  */
 package org.apache.qpid.jms.session;
 
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.Assert.assertNotNull;
 
-import javax.jms.IllegalStateException;
-import javax.jms.JMSException;
-import javax.jms.QueueSession;
-import javax.jms.Session;
+import jakarta.jms.IllegalStateException;
+import jakarta.jms.JMSException;
+import jakarta.jms.QueueSession;
+import jakarta.jms.Session;
 
 import org.apache.qpid.jms.JmsConnectionTestSupport;
 import org.apache.qpid.jms.JmsQueue;
 import org.apache.qpid.jms.JmsQueueSession;
 import org.apache.qpid.jms.JmsTopic;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInfo;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Test the contract of JmsQueueSession against JMS Spec requirements.
@@ -43,232 +40,172 @@ public class JmsQueueSessionTest extends JmsConnectionTestSupport {
     private final JmsQueue queue = new JmsQueue();
 
     @Override
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        super.setUp(testInfo);
+    @Before
+    public void setUp() throws Exception {
+        super.setUp();
         queueConnection = createQueueConnectionToMockProvider();
         queueConnection.start();
 
         queueSession = queueConnection.createQueueSession(false, Session.AUTO_ACKNOWLEDGE);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateConsumerToTopic() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createConsumer(topic);
-        });
+        queueSession.createConsumer(topic);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateReceiver() throws JMSException {
         assertNotNull(queueSession.createReceiver(queue));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateReceiverWithSelector() throws JMSException {
         assertNotNull(queueSession.createReceiver(queue, "color = red"));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateConsumerToQueue() throws JMSException {
         assertNotNull(queueSession.createConsumer(queue));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateConsumerWithSelector() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createConsumer(topic, "color = red");
-        });
+        queueSession.createConsumer(topic, "color = red");
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateConsumerToQueueWithSelector() throws JMSException {
         assertNotNull(queueSession.createConsumer(queue, "color = red"));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateConsumerWithSelectorNoLocal() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createConsumer(topic, "color = red", false);
-        });
+        queueSession.createConsumer(topic, "color = red", false);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateConsumerToQueueWithSelectorNoLocal() throws JMSException {
         assertNotNull(queueSession.createConsumer(queue, "color = red", false));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateSubscriber() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            ((JmsQueueSession) queueSession).createSubscriber(topic);
-        });
+        ((JmsQueueSession) queueSession).createSubscriber(topic);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateSubscriberSelector() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            ((JmsQueueSession) queueSession).createSubscriber(topic, "color = red", false);
-        });
+        ((JmsQueueSession) queueSession).createSubscriber(topic, "color = red", false);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateProducerToTopic() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createProducer(topic);
-        });
+        queueSession.createProducer(topic);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testCreateProducerToQueue() throws JMSException {
         assertNotNull(queueSession.createProducer(queue));
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateTopicPublisher() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            ((JmsQueueSession) queueSession).createPublisher(topic);
-        });
+        ((JmsQueueSession) queueSession).createPublisher(topic);
     }
 
     /**
      * Test that a call to <code>createDurableSubscriber()</code> method
      * on a <code>QueueSession</code> throws a
-     * <code>javax.jms.IllegalStateException</code>.
+     * <code>jakarta.jms.IllegalStateException</code>.
      * (see JMS 1.1 specs, table 4-1).
      *
      * @since JMS 1.1
      *
      * @throws JMSException if an error occurs during the test.
      */
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateDurableSubscriberOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createDurableSubscriber(topic, "subscriptionName");
-        });
+        queueSession.createDurableSubscriber(topic, "subscriptionName");
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateDurableSubscriberWithSelectorOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createDurableSubscriber(topic, "subscriptionName", "color = red", false);
-        });
+        queueSession.createDurableSubscriber(topic, "subscriptionName", "color = red", false);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateDurableConsumerOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createDurableConsumer(topic, "subscriptionName");
-        });
+        queueSession.createDurableConsumer(topic, "subscriptionName");
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateDurableConsumerWithSelectorOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createDurableConsumer(topic, "subscriptionName", "color = red", false);
-        });
+        queueSession.createDurableConsumer(topic, "subscriptionName", "color = red", false);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateSharedConsumerOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createSharedConsumer(topic, "subscriptionName");
-        });
+        queueSession.createSharedConsumer(topic, "subscriptionName");
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateSharedConsumerWithSelectorOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createSharedConsumer(topic, "subscriptionName", "color = red");
-        });
+        queueSession.createSharedConsumer(topic, "subscriptionName", "color = red");
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateSharedDurableConsumerOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createSharedDurableConsumer(topic, "subscriptionName");
-        });
+        queueSession.createSharedDurableConsumer(topic, "subscriptionName");
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateSharedDurableConsumerWithSelectorOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createSharedConsumer(topic, "subscriptionName", "color = red");
-        });
+        queueSession.createSharedConsumer(topic, "subscriptionName", "color = red");
     }
 
     /**
      * Test that a call to <code>createTemporaryTopic()</code> method
      * on a <code>QueueSession</code> throws a
-     * <code>javax.jms.IllegalStateException</code>.
+     * <code>jakarta.jms.IllegalStateException</code>.
      * (see JMS 1.1 specs, table 4-1).
      *
      * @since JMS 1.1
      *
      * @throws JMSException if an error occurs during the test.
      */
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateTemporaryTopicOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createTemporaryTopic();
-        });
+        queueSession.createTemporaryTopic();
     }
 
     /**
      * Test that a call to <code>createTopic()</code> method
      * on a <code>QueueSession</code> throws a
-     * <code>javax.jms.IllegalStateException</code>.
+     * <code>jakarta.jms.IllegalStateException</code>.
      * (see JMS 1.1 specs, table 4-1).
      *
      * @since JMS 1.1
      *
      * @throws JMSException if an error occurs during the test.
      */
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000, expected=IllegalStateException.class)
     public void testCreateTopicOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.createTopic("test-topic");
-        });
+        queueSession.createTopic("test-topic");
     }
 
     /**
      * Test that a call to <code>unsubscribe()</code> method
      * on a <code>QueueSession</code> throws a
-     * <code>javax.jms.IllegalStateException</code>.
+     * <code>jakarta.jms.IllegalStateException</code>.
      * (see JMS 1.1 specs, table 4-1).
      *
      * @since JMS 1.1
      *
      * @throws JMSException if an error occurs during the test.
      */
-    @Test
-    @Timeout(30)
-    public void testUnsubscribeOnQueueSession() throws JMSException {
-        assertThrows(IllegalStateException.class, () -> {
-            queueSession.unsubscribe("subscriptionName");
-        });
+    @Test(timeout = 30000, expected=IllegalStateException.class)
+    public void testUnsubscribeOnQueueSession() throws JMSException  {
+        queueSession.unsubscribe("subscriptionName");
     }
 }
