@@ -16,22 +16,21 @@
  */
 package org.apache.qpid.jms.destinations;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.fail;
 
-import javax.jms.Connection;
-import javax.jms.IllegalStateException;
-import javax.jms.InvalidDestinationException;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageProducer;
-import javax.jms.Session;
-import javax.jms.TemporaryQueue;
+import jakarta.jms.Connection;
+import jakarta.jms.IllegalStateException;
+import jakarta.jms.InvalidDestinationException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Session;
+import jakarta.jms.TemporaryQueue;
 
 import org.apache.qpid.jms.support.AmqpTestSupport;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -42,8 +41,7 @@ public class JmsTemporaryQueueTest extends AmqpTestSupport {
 
     protected static final Logger LOG = LoggerFactory.getLogger(JmsTemporaryQueueTest.class);
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testCreateTemporaryQueue() throws Exception {
         connection = createAmqpConnection();
         connection.start();
@@ -56,8 +54,7 @@ public class JmsTemporaryQueueTest extends AmqpTestSupport {
         assertEquals(1, brokerService.getAdminView().getTemporaryQueues().length);
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testCantConsumeFromTemporaryQueueCreatedOnAnotherConnection() throws Exception {
         connection = createAmqpConnection();
         connection.start();
@@ -80,8 +77,7 @@ public class JmsTemporaryQueueTest extends AmqpTestSupport {
         }
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testCantSendToTemporaryQueueFromClosedConnection() throws Exception {
         connection = createAmqpConnection();
         connection.start();
@@ -109,8 +105,7 @@ public class JmsTemporaryQueueTest extends AmqpTestSupport {
         }
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testCantDeleteTemporaryQueueWithConsumers() throws Exception {
         connection = createAmqpConnection();
         connection.start();
