@@ -16,37 +16,35 @@
  */
 package org.apache.qpid.jms.producer;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.util.ArrayList;
 import java.util.List;
 
-import javax.jms.JMSException;
-import javax.jms.JMSSecurityException;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageProducer;
-import javax.jms.Queue;
-import javax.jms.Session;
-import javax.jms.Topic;
+import jakarta.jms.JMSException;
+import jakarta.jms.JMSSecurityException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
+import jakarta.jms.Topic;
 
 import org.apache.activemq.broker.jmx.QueueViewMBean;
 import org.apache.activemq.broker.jmx.TopicViewMBean;
 import org.apache.qpid.jms.support.AmqpTestSupport;
 import org.apache.qpid.jms.util.StopWatch;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 
 /**
  * Test JMS Anonymous Producer functionality.
  */
 public class JmsAnonymousProducerTest extends AmqpTestSupport {
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testCreateProducer() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
@@ -59,34 +57,32 @@ public class JmsAnonymousProducerTest extends AmqpTestSupport {
         assertTrue(brokerService.getAdminView().getTotalProducerCount() == 0);
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testAnonymousSend() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         assertNotNull(session);
         MessageProducer producer = session.createProducer(null);
 
         Message message = session.createMessage();
         producer.send(queue, message);
 
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(1, proxy.getQueueSize());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testAnonymousSendToTopic() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Topic topic = session.createTopic(testMethodName);
+        Topic topic = session.createTopic(name.getMethodName());
         assertNotNull(session);
         MessageProducer producer = session.createProducer(null);
         assertNotNull(producer);
@@ -96,36 +92,32 @@ public class JmsAnonymousProducerTest extends AmqpTestSupport {
         Message message = session.createMessage();
         producer.send(topic, message);
 
-        TopicViewMBean proxy = getProxyToTopic(testMethodName);
+        TopicViewMBean proxy = getProxyToTopic(name.getMethodName());
         assertEquals(1, proxy.getEnqueueCount());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testAnonymousSendToThreeDestinations() throws Exception {
         StopWatch timer = new StopWatch();
         doTestAnonymousProducerSendToMultipleDests(3, 1);
         LOG.info("Time to send to three destinations: {} ms", timer.taken());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testAnonymousSendToTenDestinations() throws Exception {
         StopWatch timer = new StopWatch();
         doTestAnonymousProducerSendToMultipleDests(10, 1);
         LOG.info("Time to send to ten destinations: {} ms", timer.taken());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testAnonymousSendToOneHundredDestinations() throws Exception {
         StopWatch timer = new StopWatch();
         doTestAnonymousProducerSendToMultipleDests(100, 1);
         LOG.info("Time to send to one hundred destinations: {} ms", timer.taken());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testAnonymousSendToTenDestinationsTenTimes() throws Exception {
         StopWatch timer = new StopWatch();
         doTestAnonymousProducerSendToMultipleDests(10, 10);
@@ -141,7 +133,7 @@ public class JmsAnonymousProducerTest extends AmqpTestSupport {
 
         List<Queue> queues = new ArrayList<Queue>(numDestinations);
         for (int i = 0; i < numDestinations; ++i) {
-            queues.add(session.createQueue(testMethodName + i));
+            queues.add(session.createQueue(name.getMethodName() + i));
         }
 
         assertNotNull(session);
@@ -161,8 +153,7 @@ public class JmsAnonymousProducerTest extends AmqpTestSupport {
     }
 
     // TODO - Should only get JMSSecurityException on ActiveMQ 5.12.2+
-    @Test
-    @Timeout(30)
+    @Test(timeout = 30000)
     public void testAnonymousProducerNotAuthorized() throws Exception {
         connection = createAmqpConnection("guest", "password");
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
