@@ -19,8 +19,8 @@ package org.apache.qpid.jms.support;
 import java.net.URI;
 import java.util.Map;
 
-import javax.jms.Connection;
-import javax.jms.ConnectionFactory;
+import jakarta.jms.Connection;
+import jakarta.jms.ConnectionFactory;
 
 import org.apache.activemq.broker.BrokerService;
 import org.apache.activemq.broker.TransportConnector;
@@ -128,7 +128,7 @@ public class AmqpTestSupport extends QpidJmsTestSupport {
 
             return new URI(uri);
         } catch (Exception e) {
-            throw new RuntimeException(e);
+            throw new RuntimeException();
         }
     }
 
